@@ -1,6 +1,6 @@
 /*** tzraw.c -- reader for olson database zoneinfo files
  *
- * Copyright (C) 2009-2014 Sebastian Freundt
+ * Copyright (C) 2009-2016 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -167,12 +167,14 @@ static const char tzdir[] = "/usr/share/zoneinfo";
 #if defined ZONEINFO_UTC_RIGHT
 /* where can we deduce some info for our coordinated zones */
 static const char coord_fn[] = ZONEINFO_UTC_RIGHT;
-#else  /* !ZONEINFO_UTC_RIGHT */
-static const char coord_fn[] = "/usr/share/zoneinfo/right/UTC";
-#endif	/* ZONEINFO_UTC_RIGHT */
+#elif defined ZONEINFO_UTC
+static const char coord_fn[] = ZONEINFO_UTC;
+#else  /* !ZONEINFO_UTC_RIGHT && !ZONEINFO_UTC */
+static const char coord_fn[] = "/usr/share/zoneinfo/UTC";
+#endif	/* ZONEINFO_UTC_RIGHT || ZONEINFO_UTC */
 
 #define PROT_MEMMAP	PROT_READ | PROT_WRITE
-#define MAP_MEMMAP	MAP_PRIVATE | MAP_ANONYMOUS
+#define MAP_MEMMAP	MAP_PRIVATE | MAP_ANON
 
 #define AS_MUT_ZIF(x)	((struct zif_s*)deconst(x))
 
@@ -537,6 +539,7 @@ zif_open(const char *file)
 
 	/* check for special time zones */
 	if ((cz = coord_zone(file)) > TZCZ_UNK) {
+		/* use UTC file */
 		file = coord_fn;
 	}
 
@@ -614,6 +617,11 @@ __find_zrng(const struct zif_s z[static 1U], int32_t t, int min, int max)
 		res.prev = INT_MIN;
 		/* assume the first offset has always been there */
 		res.next = res.prev;
+	} else if (UNLIKELY(trno < 0)) {
+		/* special case where no transitions are recorded */
+		res.trno = 0U;
+		res.prev = INT_MIN;
+		res.next = INT_MAX;
 	} else {
 		res.trno = (uint8_t)trno;
 		if (LIKELY(trno + 1U < zif_ntrans(z))) {
