@@ -1,6 +1,6 @@
 /*** yd.c -- guts for yd dates that consist of a year and a year-day
  *
- * Copyright (C) 2010-2014 Sebastian Freundt
+ * Copyright (C) 2010-2016 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -525,6 +525,25 @@ __get_jan01_yday_dow(unsigned int yd, dt_dow_t w)
 	return (dt_dow_t)(DT_SUNDAY - res);
 }
 
+static inline __attribute__((const, pure)) unsigned int
+__get_ydays(unsigned int y)
+{
+	return LIKELY(!__leapp(y)) ? 365U : 366U;
+}
+
+DEFUN __attribute__((pure)) dt_yd_t
+__yd_fixup(dt_yd_t d)
+{
+	int ydays;
+
+	if (LIKELY(d.d <= 365)) {
+		/* trivial */
+		;
+	} else if (d.d > (ydays = __get_ydays(d.y))) {
+		d.d = ydays;
+	}
+	return d;
+}
 #endif	/* YD_ASPECT_HELPERS_ */
 
 
@@ -536,7 +555,7 @@ __get_isowk_wd(unsigned int yd, dt_dow_t f01)
 /* given the weekday the year starts with, F01, and the year-day YD
  * return the iso week number */
 	static const int_fast8_t iso[] = {2, 1, 0, -1, -2, 4, 3, 2};
-	return (yd - iso[f01]) / GREG_DAYS_P_WEEK + 1;
+	return (GREG_DAYS_P_WEEK + yd - iso[f01]) / GREG_DAYS_P_WEEK;
 }
 
 DEFUN __attribute__((const, pure)) int
@@ -546,7 +565,7 @@ __yd_get_wcnt_abs(dt_yd_t d)
  * the year started with */
 	int yd = d.d;
 	/* express yd as 7k + n relative to jan01 */
-	return (yd - 1) / 7 + 1;
+	return (GREG_DAYS_P_WEEK + yd - 1) / GREG_DAYS_P_WEEK;
 }
 
 DEFUN __attribute__((const, pure)) int
@@ -564,7 +583,8 @@ __yd_get_wcnt_iso(dt_yd_t d)
 	int wk;
 
 	/* express yd as 7k + n relative to jan01 */
-	if (UNLIKELY((wk = __get_isowk_wd(yd, (dt_dow_t)y01)) < 1)) {
+	wk = __get_isowk_wd(yd, (dt_dow_t)y01);
+	if (UNLIKELY(wk < 1)) {
 		/* get last years y01
 		 * which is basically y01 - (365|366 % 7) */
 		if (LIKELY(!__leapp(--y))) {
@@ -615,16 +635,168 @@ __yd_get_wcnt(dt_yd_t d, dt_dow_t _1st_wd)
 	/* and now express yd as 7k + n relative to jan01 */
 	return (yd - wk + 7) / 7;
 }
+
+static dt_dow_t
+__yd_get_wday(dt_yd_t this)
+{
+	unsigned int j01_wd = __get_jan01_wday(this.y);
+	if (LIKELY(j01_wd != DT_MIRACLEDAY && this.d)) {
+		unsigned int wd = (this.d - 1 + j01_wd) % GREG_DAYS_P_WEEK;
+		return (dt_dow_t)(wd ?: DT_SUNDAY);
+	}
+	return DT_MIRACLEDAY;
+}
+
+static struct __md_s
+__yd_get_md(dt_yd_t this)
+{
+	return __yday_get_md(this.y, this.d);
+}
 #endif	/* YD_ASPECT_GETTERS_ */
 
+
+#if defined ASPECT_CONV && !defined YD_ASPECT_CONV_
+#define YD_ASPECT_CONV_
+/* we need some getter stuff, so get it */
+#define ASPECT_GETTERS
+#include "yd.c"
+#undef ASPECT_GETTERS
+
+static dt_ymd_t
+__yd_to_ymd(dt_yd_t d)
+{
+	struct __md_s md = __yd_get_md(d);
+
+#if defined HAVE_ANON_STRUCTS_INIT
+	return (dt_ymd_t){.y = d.y, .m = md.m, .d = md.d};
+#else  /* !HAVE_ANON_STRUCTS_INIT */
+	dt_ymd_t res;
+	res.y = d.y;
+	res.m = md.m;
+	res.d = md.d;
+	return res;
+#endif	/* HAVE_ANON_STRUCTS_INIT */
+}
+
+static dt_daisy_t
+__yd_to_daisy(dt_yd_t d)
+{
+	if (UNLIKELY((signed int)TO_BASE(d.y) < 0)) {
+		return 0;
+	}
+	return __jan00_daisy(d.y) + d.d;
+}
+
+static dt_ymcw_t
+__yd_to_ymcw(dt_yd_t d)
+{
+	struct __md_s md = __yd_get_md(d);
+	unsigned int w = __yd_get_wday(d);
+	unsigned int c;
+
+	/* we obtain C from weekifying the month */
+	c = (md.d - 1U) / GREG_DAYS_P_WEEK + 1U;
+
+#if defined HAVE_ANON_STRUCTS_INIT
+	return (dt_ymcw_t){.y = d.y, .m = md.m, .c = c, .w = w};
+#else  /* !HAVE_ANON_STRUCTS_INIT */
+	dt_ymcw_t res;
+	res.y = d.y;
+	res.m = md.m;
+	res.c = c;
+	res.w = w;
+	return res;
+#endif	/* HAVE_ANON_STRUCTS_INIT */
+}
+
+static dt_ywd_t
+__yd_to_ywd(dt_yd_t d)
+{
+	dt_dow_t w = __yd_get_wday(d);
+	unsigned int c = __yd_get_wcnt_abs(d);
+	return __make_ywd_c(d.y, c, w, YWD_ABSWK_CNT);
+}
+#endif	/* ASPECT_CONV */
+
+
+#if defined ASPECT_ADD && !defined YD_ASPECT_ADD_
+#define YD_ASPECT_ADD_
+static __attribute__((pure)) dt_yd_t
+__yd_fixup_d(unsigned int y, signed int d)
+{
+	dt_yd_t res = {0};
+
+	if (LIKELY(d >= 1 && d <= 365)) {
+		/* all years in our design range have at least 365 days */
+		;
+	} else if (d < 1) {
+		int ydays;
+
+		do {
+			y--;
+			ydays = __get_ydays(y);
+			d += ydays;
+		} while (d < 1);
+
+	} else {
+		int ydays;
+
+		while (d > (ydays = __get_ydays(y))) {
+			d -= ydays;
+			y++;
+		}
+	}
+
+	res.y = y;
+	res.d = d;
+	return res;
+}
+
+static dt_yd_t
+__yd_add_d(dt_yd_t d, int n)
+{
+/* add N days to D */
+	signed int tgtd = d.d + n;
+
+	/* fixup the day */
+	return __yd_fixup_d(d.y, tgtd);
+}
+
+static dt_yd_t
+__yd_add_b(dt_yd_t d, int n)
+{
+/* add N business days to D */
+	dt_dow_t wd = __yd_get_wday(d);
+	int tgtd = d.d + __get_d_equiv(wd, n);
+
+	/* fixup the day, i.e. 2012-0367 -> 2013-001 */
+	return __yd_fixup_d(d.y, tgtd);
+}
+
+static dt_yd_t
+__yd_add_w(dt_yd_t d, int n)
+{
+/* add N weeks to D */
+	return __yd_add_d(d, GREG_DAYS_P_WEEK * n);
+}
+
+static dt_yd_t
+__yd_add_y(dt_yd_t d, int n)
+{
+/* add N years to D */
+	d.y += n;
+	return d;
+}
+#endif	/* ASPECT_ADD */
+
 
 #if defined ASPECT_DIFF && !defined YD_ASPECT_DIFF_
 #define YD_ASPECT_DIFF_
-static __attribute__((const, pure)) struct dt_d_s
+static __attribute__((const, pure)) struct dt_ddur_s
 __yd_diff(dt_yd_t d1, dt_yd_t d2)
 {
 /* compute d2 - d1 entirely in terms of ymd but express the result as yd */
-	struct dt_d_s res = {.typ = DT_YD, .dur = 1};
+	struct dt_ddur_s res = dt_make_ddur(DT_DURYD, 0);
 	signed int tgtd;
 	signed int tgty;
 
