@@ -1,6 +1,6 @@
 /*** dzone.c -- convert date/times between timezones
  *
- * Copyright (C) 2011-2014 Sebastian Freundt
+ * Copyright (C) 2011-2016 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -46,6 +46,7 @@
 #include "dt-core.h"
 #include "dt-io.h"
 #include "dt-core-tz-glue.h"
+#include "dt-locale.h"
 #include "tzraw.h"
 
 struct ztr_s {
@@ -136,8 +137,12 @@ dz_write_nxtr(struct zrng_s r, zif_t z, const char *zn)
 		/* thank god there's another one */
 		struct ztrdtl_s zd = zif_trdtl(z, r.trno + 1);
 
+		if (r.next == INT_MAX) {
+			goto never;
+		}
 		bp += dz_strftr(bp, ep - bp, (struct ztr_s){r.next, zd.offs});
 	} else {
+	never:
 		bp += xstrlcpy(bp, never, bp - ep);
 	}
 
@@ -198,11 +203,11 @@ main(int argc, char *argv[])
 	struct {
 		zif_t zone;
 		const char *name;
-	} *z;
-	size_t nz;
+	} *z = NULL;
+	size_t nz = 0U;
 	/* all them datetimes to consider */
-	struct dt_dt_s *d;
-	size_t nd;
+	struct dt_dt_s *d = NULL;
+	size_t nd = 0U;
 	bool trnsp = false;
 
 	if (yuck_parse(argi, argc, argv)) {
@@ -214,6 +219,10 @@ main(int argc, char *argv[])
 		goto out;
 	}
 
+	if (argi->from_locale_arg) {
+		setilocale(argi->from_locale_arg);
+	}
+
 	/* try and read the from and to time zones */
 	if (argi->from_zone_arg) {
 		fromz = dt_io_zone(argi->from_zone_arg);
@@ -221,6 +230,10 @@ main(int argc, char *argv[])
 	if (argi->next_flag || argi->prev_flag) {
 		trnsp = true;
 	}
+	if (argi->base_arg) {
+		struct dt_dt_s base = dt_strpdt(argi->base_arg, NULL, NULL);
+		dt_set_base(base);
+	}
 
 	/* very well then */
 	fmt = argi->input_format_args;
@@ -230,9 +243,15 @@ main(int argc, char *argv[])
 	 * we'll then sort them by traversing the input args and ass'ing
 	 * to the one or the other */
 	nz = 0U;
-	z = malloc(argi->nargs * sizeof(*z));
+	if (UNLIKELY((z = malloc(argi->nargs * sizeof(*z))) == NULL)) {
+		error("failed to allocate space for zone info");
+		goto out;
+	}
 	nd = 0U;
-	d = malloc(argi->nargs * sizeof(*d));
+	if (UNLIKELY((d = malloc(argi->nargs * sizeof(*d))) == NULL)) {
+		error("failed to allocate space for date/times");
+		goto out;
+	}
 
 	for (size_t i = 0U; i < argi->nargs; i++) {
 		const char *inp = argi->args[i];
@@ -301,17 +320,24 @@ nor a date/time corresponding to the given input formats", inp);
 		}
 	}
 
+out:
 	/* release the zones */
 	dt_io_clear_zones();
 	/* release those arrays */
-	free(z);
-	free(d);
+	if (LIKELY(z != NULL)) {
+		free(z);
+	}
+	if (LIKELY(d != NULL)) {
+		free(d);
+	}
 
-	if (argi->from_zone_arg) {
+	if (fromz != NULL) {
 		zif_close(fromz);
+	}
+	if (argi->from_locale_arg) {
+		setilocale(NULL);
 	}
 
-out:
 	yuck_free(argi);
 	return rc;
 }
